portal.ui.commands


*state*clj/s

source

center-selectedclj/s

(center-selected _state)
source

clearclj/s

(clear state)
source

clear-filterclj/s

(clear-filter state)
source

closeclj/s

(close)
(close state)
source

copyclj/s

(copy state)

Copy selected value as an edn string to the clipboard.

Copy selected value as an edn string to the clipboard.
sourceraw docstring

copy-jsonclj/s

(copy-json state)

Copy selected value as a json string to the clipboard.

Copy selected value as a json string to the clipboard.
sourceraw docstring

(copy-link state)

Copy link to the standalone Portal (https://djblue.github.io/portal/).

Copy link to the standalone Portal (https://djblue.github.io/portal/).
sourceraw docstring

copy-pathclj/s

(copy-path state)

Copy the path from the root value to the currently selected item.

Copy the path from the root value to the currently selected item.
sourceraw docstring

copy-strclj/s

(copy-str state)

Copy string to the clipboard.

Copy string to the clipboard.
sourceraw docstring

expand-incclj/s

(expand-inc state)

Expand 1 additional layer of children from selected values.

Expand 1 additional layer of children from selected values.
sourceraw docstring

focus-filterclj/s

(focus-filter _)
source

focus-selectedclj/s

(focus-selected state)
source

history-backclj/s

(history-back state)
source

history-firstclj/s

(history-first state)
source

history-forwardclj/s

(history-forward state)
source

history-lastclj/s

(history-last state)
source

inspect-standaloneclj/s

(inspect-standalone state)

Open value in standalone Portal (https://djblue.github.io/portal/).

Open value in standalone Portal (https://djblue.github.io/portal/).
sourceraw docstring

make-commandclj/s

(make-command {:keys [name command predicate args f] :as opts})
source

openclj/s

(open f)
(open state f)
source

open-command-paletteclj/s

(open-command-palette state)

Show All Commands

Show All Commands
sourceraw docstring

open-fileclj/s

(open-file state)

Open a File

Open a File
sourceraw docstring

paletteclj/s

(palette)
(palette options)
source

palette*clj/s

(palette* {:keys [container]})
source

parse-selectedclj/s

(parse-selected _state)

Parse currently select text

Parse currently select text
sourceraw docstring

pasteclj/s

(paste state)

Paste value from clipboard

Paste value from clipboard
sourceraw docstring

pick-inclj/s

(pick-in v)
(pick-in state v)
source

pick-manyclj/s

(pick-many options)
(pick-many state options)

Prompt user to pick many values from a list of options.

NOTE: Will return :portal.ui.commands/dismiss if prompt is dimissed by the user.

Prompt user to pick many values from a list of options.

NOTE: Will return `:portal.ui.commands/dismiss` if prompt is dimissed by the user.
sourceraw docstring

pick-oneclj/s

(pick-one options)
(pick-one state options)

Prompt user to pick one value from a list of options.

NOTE: Will return :portal.ui.commands/dismiss if prompt is dimissed by the user.

Prompt user to pick one value from a list of options.

NOTE: Will return `:portal.ui.commands/dismiss` if prompt is dimissed by the user.
sourceraw docstring

pprintclj/s

(pprint value)

Pretty print selected value to a string

Pretty print selected value to a string
sourceraw docstring

register!clj/s

(register! var)
(register! var opts)
source

scroll-bottomclj/s

(scroll-bottom _state)
source

scroll-topclj/s

(scroll-top _state)
source

search-refsclj/s

source

select-childclj/s

(select-child state)
source

select-columnsclj/s

(select-columns value ks)

Select column from list-of-maps or map-of-maps.

Select column from list-of-maps or map-of-maps.
sourceraw docstring

select-nextclj/s

(select-next state)
source

select-next-viewerclj/s

(select-next-viewer state)
source

select-noneclj/s

(select-none state)

Deselect all values.

Deselect all values.
sourceraw docstring

select-parentclj/s

(select-parent state)
source

select-popclj/s

(select-pop state)
source

select-prevclj/s

(select-prev state)
source

select-prev-viewerclj/s

(select-prev-viewer state)
source

select-rootclj/s

(select-root state)
source

select-viewerclj/s

(select-viewer state)

Set the viewer for the currently selected value(s).

Set the viewer for the currently selected value(s).
sourceraw docstring

set-themeclj/s

(set-theme state)
source

shortcutclj/s

(shortcut command)
source

show-rpc-logclj/s

(show-rpc-log state)

Show up to the last 10 RPC the Portal UI has made.

Show up to the last 10 RPC the Portal UI has made.
sourceraw docstring

toggle-expandclj/s

(toggle-expand state)

Expand or collapse currently selected values.

Expand or collapse currently selected values.
sourceraw docstring

toggle-shellclj/s

(toggle-shell state)

Toggle visibility of top / bottom helper UX. Allows for a value focused session.

Toggle visibility of top / bottom helper UX. Allows for a value focused session.
sourceraw docstring

transpose-mapclj/s

(transpose-map value)

Transpose a map.

Transpose a map.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries